sampling - Kerasy Documentation
Author: Shuto
Description: Brief explanation of sampling and introduction of modules that can be used in Kerasy

### Sampling

- 2019-11-29(金)
- ML/sampling.py

Notebook

Example Notebook: Kerasy.examples.sampling.ipynb

## Rejection Sampling

    class kerasy.ML.sampling.RejectionSampler(p, q, domain, k=1, **qargs)

## Metropolis-Hastings

    class kerasy.ML.sampling.MHSampler(p, q, **qargs)

## GibbsMsphereSampler

    class kerasy.ML.sampling.GibbsMsphereSampler(M, r=1)

Reference

- Pattern Recognition and Machine Learning by Christopher Bishop

« Previous Next »